@@ -18,4 +18,9 @@ def lint(session):
 def typecheck(session):
     session.install("-r", "requirements.txt")
     session.install("mypy")
-    session.run("mypy", "./azure/")
\ No newline at end of file
+    session.run("mypy", "./azure/")
+
+@nox.session(python=["3.7", "3.8"])
+def autopep(session):
+    session.install("-r", "requirements.txt")
+    session.run("autopep8", "--in-place --aggressive --aggressive --recursive \"./azure/\"")
\ No newline at end of file
